@@ -128,8 +128,8 @@ func GetRDMADevices() []RDMADevice {
 
 // finalizeRDMADevice derives the network interface from the device name
 func finalizeRDMADevice(device *RDMADevice) {
-	if strings.HasPrefix(device.Name, "rdma_") {
-		device.Interface = strings.TrimPrefix(device.Name, "rdma_")
+	if ifaceName, ok := strings.CutPrefix(device.Name, "rdma_"); ok {
+		device.Interface = ifaceName
 	}
 }
 
